.. _api:

API
===


sitemapper.sitemaps
-------------------

.. autoclass:: sitemapper.sitemaps.SitemapBase
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: sitemapper.sitemaps.Sitemap
   :members:
   :undoc-members:
   :show-inheritance:


sitemapper.models
-----------------

.. automodule:: sitemapper.models
   :members:
